@@ -1,4 +1,4 @@
-import subprocess, os, struct, re, datetime
+import struct, re, datetime
 import hglib
 from hglib import error, util, templates, merge, context
 
@@ -568,8 +568,12 @@ class hgclient(object):
                           close_branch=closebranch, d=date, u=user, l=logfile,
                           I=include, X=exclude, amend=amend)
         out = self.rawcommand(args)
-        rev, node = out.splitlines()[-1].rsplit(b(':'))
-        return int(rev.split()[-1]), node
+        m = re.search(b(r'^committed changeset (\d+):([0-9a-f]+)'), out,
+                      re.MULTILINE)
+        if not m:
+            raise ValueError('revision and node not found in hg output: %r' % out)
+        rev, node = m.groups()
+        return int(rev), node
 
     def config(self, names=[], untrusted=False, showsource=False):
         """Return a list of (section, key, value) config settings from all
@@ -1627,7 +1631,10 @@ class hgclient(object):
         return self._version
 
     def __getitem__(self, changeid):
-        return context.changectx(self, changeid)
+        try:
+            return context.changectx(self, changeid)
+        except ValueError as e:
+            raise KeyError(*e.args)
 
     def __contains__(self, changeid):
         """
