@@ -1,4 +1,6 @@
-import common, hglib
+from tests import common
+import hglib
+from hglib.util import b
 
 class test_branches(common.basetest):
     def test_empty(self):
@@ -6,10 +8,10 @@ class test_branches(common.basetest):
 
     def test_basic(self):
         self.append('a', 'a')
-        rev0 = self.client.commit('first', addremove=True)
-        self.client.branch('foo')
+        rev0 = self.client.commit(b('first'), addremove=True)
+        self.client.branch(b('foo'))
         self.append('a', 'a')
-        rev1 = self.client.commit('second')
+        rev1 = self.client.commit(b('second'))
         branches = self.client.branches()
 
         expected = []
